==> gatling-recorder-2.1.1-sources.jar: io/gatling/recorder/http/ssl/TrustManagerFactory.scala <==
/**
 * Copyright 2011-2014 eBusiness Information, Groupe Excilys (www.ebusinessinformation.fr)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * 		http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.gatling.recorder.http.ssl

import java.security.KeyStore
import java.security.cert.X509Certificate
import javax.net.ssl._

object TrustManagerFactory {

  val LooseTrustManagers = Array[TrustManager](new X509TrustManager {

    def getAcceptedIssuers = Array.empty[X509Certificate]

    def checkClientTrusted(chain: Array[X509Certificate], authType: String): Unit = { /* Always trust */ }

    def checkServerTrusted(chain: Array[X509Certificate], authType: String): Unit = { /* Always trust */ }
  })
}

/**
 * Bogus {@link TrustManagerFactorySpi} which accepts any certificate even if it
 * is invalid.
 */
class TrustManagerFactory extends TrustManagerFactorySpi {

  def engineGetTrustManagers = TrustManagerFactory.LooseTrustManagers

  def engineInit(keystore: KeyStore): Unit = { /* Unused */ }

  def engineInit(managerFactoryParameters: ManagerFactoryParameters): Unit = { /* Unused */ }
}

==> gatling-recorder-2.2.1-sources.jar: io/gatling/recorder/http/ssl/TrustManagerFactory.scala <==
/**
 * Copyright 2011-2016 GatlingCorp (http://gatling.io)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.gatling.recorder.http.ssl

import java.security.KeyStore
import java.security.cert.X509Certificate
import javax.net.ssl._

private[ssl] object TrustManagerFactory {

  val LooseTrustManagers = Array[TrustManager](new X509TrustManager {

    def getAcceptedIssuers = Array.empty[X509Certificate]

    def checkClientTrusted(chain: Array[X509Certificate], authType: String): Unit = { /* Always trust */ }

    def checkServerTrusted(chain: Array[X509Certificate], authType: String): Unit = { /* Always trust */ }
  })
}

/**
 * Bogus TrustManagerFactorySpi which accepts any certificate even if it
 * is invalid.
 */
private[ssl] class TrustManagerFactory extends TrustManagerFactorySpi {

  def engineGetTrustManagers = TrustManagerFactory.LooseTrustManagers

  def engineInit(keystore: KeyStore): Unit = { /* Unused */ }

  def engineInit(managerFactoryParameters: ManagerFactoryParameters): Unit = { /* Unused */ }
}
